#!/bin/bash
#
# source: http://switch.dl.sourceforge.net/sourceforge/gimp-print/gutenprint-5.2.3.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="gutenprint"
softversion="5.2.3"
arch="i486"
cpu="i686"
packageversion="54.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $soft-$softversion.tar.bz2
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC >> $dest/install/slack-desc
#  HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.         

          |-----handy-ruler-----------------------------------------------------|
gutenprint: Gutenprint  is a suite of printer drivers for UNIX and Linux
gutenprint:
gutenprint: Gutenprint, formerly named Gimp-Print, is a suite of printer drivers
gutenprint: that may be used with most common UNIX print spooling systems,
gutenprint: including CUPS, lpr, LPRng, or others.
gutenprint:
gutenprint:
gutenprint:
gutenprint:
gutenprint:
gutenprint:
EODESC

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
   --prefix=/usr \
   --mandir=/usr/man \
   --enable-static=no \
   --enable-cups-ppds=no \
   --enable-escputil \
   --enable-static-genppd \
   --without-foomatic

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

find $dest/usr/man -type f -exec gzip -9 {} \;

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a  ABOUT-NLS AUTHORS COPYING INSTALL NEWS README* \
   $dest/usr/doc/$soft-$softversion
 ( cd $dest/usr/doc/$soft-$softversion
    ln -sf /usr/share/gutenprint/doc .
    ln -sf /usr/share/gutenprint/samples .
  )
rm -f $dest/usr/share/gutenprint/doc/*.pdf

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5